@@ -1,6 +1,5 @@
 from .gql_handler import *
 from datetime import datetime
-import asyncio
 
 class PyXploraApi:
     def __init__(self, countryPhoneNumber: str, phoneNumber: str, password: str, userLang: str, timeZone: str, watchNo: int=0) -> None:
@@ -50,7 +49,7 @@ class PyXploraApi:
         self.school_silent_mode = []
 
     def version(self) -> str:
-        return "1.0.29"
+        return "1.0.30"
 
 ##### Contact Info #####
     def getContacts(self) -> list:
@@ -127,16 +126,6 @@ class PyXploraApi:
     def getWatchBattery(self) -> int:
         self.getWatchLocate()
         return self.watch_last_location['battery']
-    async def __getWatchBattery_a(self) -> int:
-        await self.__askWatchLocate_async()
-        await asyncio.sleep(15)
-        self.watch_last_location = (await self.__handler.getWatchLastLocation_a(self.watch_user_id))['watchLastLocate']
-        if self.watch_last_location != None:
-            if (int(datetime.timestamp(datetime.now())) - self.watch_last_location['tm']) < 30:
-                return self.watch_last_location['battery']
-        watch_location = await self.__askHelper()
-        await asyncio.sleep(1)
-        return watch_location['battery']
     def getWatchIsCharging(self) -> bool:
         self.getWatchLocate()
         try:
@@ -219,15 +208,12 @@ class PyXploraApi:
         self.__login()
         return self.__handler.trackWatch(self.watch_user_id)['trackWatch']
     def askWatchLocate(self) -> bool:
-        self.__login()
+        self.update()
         return self.__handler.askWatchLocate(self.watch_user_id)['askWatchLocate']
-    async def __askWatchLocate_async(self) -> bool:
-        self.__login()
-        return (await self.__handler.askWatchLocate_a(self.watch_user_id))['askWatchLocate']
 
 ##### Feature #####
     def schoolSilentMode(self) -> list:
-        self.__login()
+        self.update()
         for sientTime in self.__handler.silentTimes(self.watch_user_id)['silentTimes']:
             self.school_silent_mode.append({
                 'id': sientTime['id'],
